resultFactory abstract method
T
resultFactory(
- dynamic json
Returns a result of type T deserialzied from the json.
Implementation
T resultFactory(dynamic json);
Returns a result of type T deserialzied from the json.
T resultFactory(dynamic json);